@@ -2,14 +2,14 @@
 
 #' Stat for density ridgeline plots
 #'
-#' This stat is the default stat used by [`geom_density_ridges`]. It is very similar to [`stat_density`],
+#' This stat is the default stat used by [`geom_density_ridges`]. It is very similar to [ggplot2::stat_density],
 #' however there are a few differences. Most importantly, the density bandwidth is chosen across
 #' the entire dataset.
 #'
 #' @param geom The geometric object to use to display the data.
 #' @param bandwidth Bandwidth used for density calculation. If not provided, is estimated from the data.
 #' @param from,to The left and right-most points of the grid at which the density is to be estimated,
-#'   as in [`density()`]. If not provided, these are estimated from the data range and the bandwidth.
+#'   as in [stats::density()]. If not provided, these are estimated from the data range and the bandwidth.
 #' @param jittered_points If `TRUE`, carries the original point data over to the processed data frame,
 #'   so that individual points can be drawn by the various ridgeline geoms. The specific position of these
 #'   points is controlled by various position objects, e.g. [`position_points_sina()`] or [`position_raincloud()`].
@@ -99,7 +99,9 @@ stat_density_ridges <- function(mapping = NULL, data = NULL, geom = "density_rid
 StatDensityRidges <- ggproto("StatDensityRidges", Stat,
   required_aes = "x",
 
-  default_aes = aes(height = after_stat(density)),
+  default_aes = aes(height = after_stat(density), weight = NULL),
+
+  dropped_aes = "weight",
 
   calc_panel_params = function(data, params) {
     if (is.null(params$bandwidth)) {
@@ -166,8 +168,15 @@ StatDensityRidges <- ggproto("StatDensityRidges", Stat,
     }
     panel_id <- as.numeric(panel)
 
+    if (is.null(data$weight)) {
+      weights <- NULL
+    } else {
+      weights <- data$weight / sum(data$weight)
+    }
+
     d <- stats::density(
       data$x,
+      weights = weights,
       bw = bandwidth[panel_id], from = from[panel_id], to = to[panel_id], na.rm = TRUE,
       n = n
     )
