@@ -12,7 +12,12 @@ test_that("basic tests", {
   expect_equal(d$colour, rep(c("#F00000", "#0000F0"), 13))
 
   # make sure there is no legend being generated
-  expect_equal("guide-box" %in% ggplotGrob(p)$layout$name, FALSE)
+  # in ggplot2 >= 3.5.0 legend structure in gtable changed
+  if ("get_guide_data" %in% getNamespaceExports("ggplot2")) {
+    expect_null(get_guide_data(p, "colour"))
+  } else {
+    expect_equal("guide-box" %in% ggplotGrob(p)$layout$name, FALSE)
+  }
 
   # once again, different aesthetic, different cyclical pattern, now with legend
   p <- ggplot(df, aes(x, y, label=letters, color=factor(x))) + geom_text() +
@@ -23,7 +28,12 @@ test_that("basic tests", {
   expect_equal(d$colour[order(d$x)], rep(c("#F00000", "#0000F0", "#F0F000"), 9)[1:26])
 
   # make sure there is a legend
-  expect_equal("guide-box" %in% ggplotGrob(p)$layout$name, TRUE)
+  # in ggplot2 >= 3.5.0 legend structure in gtable changed
+  if ("get_guide_data" %in% getNamespaceExports("ggplot2")) {
+    expect_s3_class(get_guide_data(p, "colour"), "data.frame")
+  } else {
+    expect_equal("guide-box" %in% ggplotGrob(p)$layout$name, TRUE)
+  }
 
   # test that breaks must match labels
   expect_error(
@@ -50,6 +60,6 @@ test_that("visual appearance of scale_*_cyclical", {
 
   p <- ggplot(df, aes(x, y, color = factor(x))) + geom_point(size = 3) +
     scale_color_cyclical(values = c("#F00000", "#00F000", "#0000F0"), guide = "legend")
-  expect_doppelganger("scale_fill_cyclical red-green-blue dots, with legend", p)
+  expect_doppelganger("scale_fill_cyclical red-green-blue dots, w legend", p)
 
 })
